/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsIPop3Protocol;
interface nsISupportsArray;
interface nsIMsgFolder;
interface nsIUrlListener;
interface nsIMsgWindow;

[scriptable, uuid(98d50234-6c8a-4875-815b-40e0178a13bd)]
interface nsIPop3IncomingServer : nsISupports {
  attribute boolean leaveMessagesOnServer;
  attribute boolean headersOnly;
  attribute boolean deleteMailLeftOnServer;
  attribute boolean dotFix;
  attribute unsigned long pop3CapabilityFlags;
  attribute boolean deleteByAgeFromServer;
  attribute long numDaysToLeaveOnServer;
  attribute nsIPop3Protocol runningProtocol;
  // client adds uidls to mark one by one, then calls markMessages
  void addUidlToMark(in string aUidl, in PRInt32 newStatus);
  void markMessages();
  attribute boolean authenticated;
  /* account to which this server defers storage, for global inbox */
  attribute ACString deferredToAccount;
  // whether get new mail in deferredToAccount gets
  // new mail with this server.
  attribute boolean deferGetNewMail;
  void downloadMailFromServers(in nsISupportsArray aServers, 
                              in nsIMsgWindow aMsgWindow,
                              in nsIMsgFolder aFolder, 
                              in nsIUrlListener aListener);
};


